curver package
==============

.. automodule:: curver

Subpackages
-----------

curver.kernel
~~~~~~~~~~~~~

.. automodule:: curver.kernel

.. rubric:: Classes

.. autosummary::
    :toctree: ../generated
    :nosignatures:
    :template: summary.rst

    ~arc.Arc
    ~arc.MultiArc
    ~crush.Crush
    ~crush.Lift
    ~curve.Curve
    ~curve.MultiCurve
    ~curvegraph.CurveGraph
    ~encoding.Encoding
    ~encoding.Mapping
    ~encoding.MappingClass
    ~error.AbortError
    ~error.AssumptionError
    ~homology.HomologyClass
    ~lamination.Lamination
    ~mappingclassgroup.MappingClassGroup
    ~moves.EdgeFlip
    ~moves.FlipGraphMove
    ~moves.Isometry
    ~moves.Move
    ~partition.CurvePartitionGraph
    ~permutation.Permutation
    ~triangulation.Edge
    ~triangulation.Triangle
    ~triangulation.Triangulation
    ~twist.HalfTwist
    ~twist.Twist

Submodules
----------

curver.load module
~~~~~~~~~~~~~~~~~~

.. automodule:: curver.load
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:

